@@ -18,6 +18,7 @@ The following cleaning functions are available:
    fillVisits
    fillMissing
    flattenHierarchical
+   codeToNumeric
    parseSpirometryData
    makeNa
 
@@ -53,7 +54,8 @@ that should be loaded.
 """
 
 
-import logging
+import functools as ft
+import              logging
 
 import numpy            as np
 import pandas           as pd
@@ -274,30 +276,56 @@ def flattenHierarchical(dtable,
 
 
 @custom.cleaner()
-def codeToNumeric(dtable, vid, name=None):
+def codeToNumeric(dtable, vid, name=None, scheme='node'):
     """codeToNumeric()
     Convert hierarchical coding labels to numeric equivalents (node IDs).
 
     Given a hierarchical variable which contains alpha-numeric codings, this
-    function will replace the codings with numeric equivalents (node IDs).
+    function will replace the codings with numeric equivalents.
 
-    For example, UKB data field 41202 (ICD10 diagnoses) uses `data coding 19
+    For example, UKB data field 41270 (ICD10 diagnoses) uses `data coding 19
     <https://biobank.ctsu.ox.ac.uk/crystal/coding.cgi?id=19>`_, which uses
-    alpha-numeric codings to denote medical diagnoses.
+    ICD10 alpha-numeric codes to denote medical diagnoses.
 
-    For data field 41202, ``codeToNumeric`` would replace coding ``D730``
-    with the corresponding node ID ``22180``.
+    For data field 41270, ``codeToNumeric`` would replace coding ``D730``
+    with the corresponding node ID ``22180`` when using the ``'node'``
+    conversion scheme, or ``39730`` when using the ``'alpha'`` scheme.
 
     The ``name`` option is unnecessary in most cases, but may be used to
-    specify an encoding scheme to use. Currently, ``'icd9'``, ``'icd10'``,
+    specify which encoding scheme to use. Currently, ``'icd9'``, ``'icd10'``,
     ``'opsc3'`` and ``'opsc4'`` are accepted.
+
+    The ``scheme`` option determines the conversion method - it can be set
+    to one of:
+
+      - ``'node'`` (default): Convert alpha-numeric codes to the corresponding
+        numeric node IDs, as specified in the UK Biobank showcase.
+
+      - ``'alpha'``: Convert alpha-numeric codes to integer numbers, using an
+        immutable scheme that will not change over time - this scheme uses the
+        :func:`.icd10.toNumeric` function.
+
+    .. warning:: Note that node IDs (which are used by the ``'node'``
+                 conversion scheme) are not present for non-leaf nodes in all
+                 hierarchical UK Biobank data fields (in which case this
+                 function will return `nan`). Also note that node IDS **may
+                 change across UK Biobank showcase releases**.
+
+    .. warning:: The ``'alpha'`` conversion scheme is intended for use with
+                 ICD10 alpha-numeric codes (and similar coding schemes). This
+                 scheme may result in unrepresentable integer values if used
+                 with longer strings.
     """
 
     hier = hierarchy.getHierarchyFilePath(dtable, vid, name=name)
     hier = hierarchy.loadHierarchyFile(hier)
 
-    def convert(code):
-        return hierarchy.codeToNumeric(code, hier=hier)
+    if scheme == 'node':
+        convert = ft.partial(hierarchy.codeToNumeric, hier=hier)
+    elif scheme == 'alpha':
+        convert = icd10.toNumeric
+    else:
+        raise ValueError(f'Invalid value for scheme option: {scheme}')
 
     cols  = [c.name for c in dtable.columns(vid)]
     codes = dtable[:, cols]
