@@ -5,9 +5,10 @@
 # Author: Paul McCarthy <pauldmccarthy@gmail.com>
 #
 """This module contains functions for parsing ``funpack`` command line
-arguments and configuration files. A ``funpack`` configuration file
-is simply a plain-text file which contains command-line options,
-sans-hyphens.
+arguments and configuration files.
+
+A ``funpack`` configuration file is simply a plain-text file which contains
+command-line options, sans-hyphens.
 """
 
 
@@ -20,7 +21,6 @@ import                    shlex
 import                    logging
 import                    argparse
 import                    collections
-import numpy           as np
 
 import funpack
 import funpack.util           as util
@@ -56,14 +56,17 @@ CLI_ARGUMENTS              = collections.OrderedDict((
                                         'default' : DEFAULT_MERGE_AXIS}),
         (('ms',  'merge_strategy'),    {'choices' : AVAILABLE_MERGE_STRATEGIES,
                                         'default' : DEFAULT_MERGE_STRATEGY}),
-        (('rm',  'remove_duplicates'), {'action' : 'store_true'}),
-        (('rd',  'rename_duplicates'), {'action' : 'store_true'}),
-        (('cfg', 'config_file'),       {'action'  : 'append'}),
-        (('vf',  'variable_file'),     {'action'  : 'append'}),
-        (('df',  'datacoding_file'),   {'action'  : 'append'}),
-        (('tf',  'type_file'),         {}),
-        (('pf',  'processing_file'),   {}),
-        (('cf',  'category_file'),     {})]),
+        (('rm',  'remove_duplicates'), {'action'  : 'store_true'}),
+        (('rd',  'rename_duplicates'), {'action'  : 'store_true'}),
+        (('cfg', 'config_file'),       {'action'  : 'append',
+                                        'type'    : util.findConfigFile}),
+        (('vf',  'variable_file'),     {'action'  : 'append',
+                                        'type'    : util.findTableFile}),
+        (('df',  'datacoding_file'),   {'action'  : 'append',
+                                        'type'    : util.findTableFile}),
+        (('tf',  'type_file'),         {'type'    : util.findTableFile}),
+        (('pf',  'processing_file'),   {'type'    : util.findTableFile}),
+        (('cf',  'category_file'),     {'type'    : util.findTableFile})]),
 
     ('Import options', [
         (('s',  'subject'),          {'action' : 'append'}),
@@ -74,6 +77,7 @@ CLI_ARGUMENTS              = collections.OrderedDict((
         (('ex', 'exclude'),          {'action' : 'append'}),
         (('ev', 'exclude_variable'), {'action' : 'append'}),
         (('ec', 'exclude_category'), {'action' : 'append'}),
+        (('aa', 'add_aux_vars'),     {'action' : 'store_true'}),
         (('iv', 'index_visits'),     {'action' : 'store_true'}),
         (('tt', 'trust_types'),      {'action' : 'store_true'})]),
 
@@ -157,10 +161,12 @@ CLI_ARGUMENTS              = collections.OrderedDict((
         (('nj', 'num_jobs'),     {'type'    : int,
                                   'default' : 1}),
         (('p',  'plugin_file'),  {'action'  : 'append',
-                                  'metavar' : 'FILE'}),
+                                  'metavar' : 'FILE',
+                                  'type'    : util.findPluginFile}),
         (('ow', 'overwrite'),    {'action'  : 'store_true'}),
         (('n',  'noisy'),        {'action'  : 'count'}),
-        (('q',  'quiet'),        {'action'  : 'store_true'})])))
+        (('q',  'quiet'),        {'action'  : 'store_true'}),
+        (('eh', 'echo'),         {'action'  : 'append'})])))
 
 
 CLI_DESCRIPTIONS = {
@@ -294,6 +300,12 @@ CLI_ARGUMENT_HELP = {
     'Category ID or label to exclude. Takes precedence over the --variable '
     'and --category options. Can be used multiple times.',
 
+    'add_aux_vars' :
+    'Automatically import auxillary variables which are specified in '
+    'processing rules if not already selected. Note that this only affects '
+    'auxillary variables - see the "take" option to the binariseCategorical '
+    'processing function for an example of an auxillary variable.',
+
     'index_visits' :
     'If set, the data is re-arranged so that visits form part of the row '
     'indices, rather than being stored in separate columns for each variable. '
@@ -426,6 +438,10 @@ CLI_ARGUMENT_HELP = {
     'overwrite'    : 'Overwrite output file if it already exists',
     'noisy'        : 'Print debug statements. Can be used up to three times.',
     'quiet'        : 'Be quiet.',
+    'echo'         : 'Echo the given value when parsed. This option is '
+                     'intended for use within FUNPACK configuration files, '
+                     'for example to print out the configuration file '
+                     'version.',
 }
 
 
@@ -561,21 +577,12 @@ def loadConfigFile(cfgfile, namespace=None):
 
     argv = []
 
-    # If the specified config file does
-    # not exist, assume it is a reference
-    # to a built-in config file
-    if not op.exists(cfgfile):
-        if not cfgfile.endswith('.cfg'):
-            cfgfile = cfgfile + '.cfg'
-        moddir   = op.dirname(op.abspath(__file__))
-        cfgfile = op.join(moddir, 'configs', cfgfile)
-
     log.debug('Loading arguments from configuration file %s', cfgfile)
 
     with open(cfgfile, 'rt') as f:
-        lines = [line.strip() for line in f.readlines()]
-        lines = [line         for line in lines if line != '']
-        lines = [line         for line in lines if not line.startswith('#')]
+        lines = [line.rsplit('#')[0] for line in f.readlines()]
+        lines = [line.strip()        for line in lines]
+        lines = [line                for line in lines if line != '']
 
     for line in lines:
         words        = list(shlex.split(line))
@@ -660,8 +667,10 @@ def parseArgs(argv=None, namespace=None):
     if args.noisy is None: args.noisy = 0
     if args.quiet:         args.noisy = 0
 
+    if args.echo is None:
+        args.echo = []
+
     _prepareInputAndOutputFiles(        args)
-    _prepareTableFiles(                 args)
     _prepareAuxFileNames(               args)
     _prepareSubjectAndVariableSelectors(args)
     _prepareCategorySelectors(          args)
@@ -737,48 +746,6 @@ def _prepareInputAndOutputFiles(args):
     args.var_format = var_format
 
 
-def _prepareTableFiles(args):
-    """Sub-function of :func:`parseArgs`. Prepares arguments related to
-    the input table files.
-
-    :arg args: ``argparse.Namespace`` object.
-    """
-
-    # The variable_file, datacoding_file, type_file,
-    # processing_file, and category_file options
-    # can be specified relative to funpackdir
-    configdir = op.join(op.dirname(__file__), 'configs')
-
-    def fixPath(f):
-
-        if f is None:
-            return f
-
-        options = [
-            f,
-            op.join(configdir, f),
-            op.join(configdir, f.replace('.', op.sep) + '.tsv')
-        ]
-
-        for o in options:
-            if op.exists(o):
-                return o
-
-        # if the fixed version does not
-        # exist, allow processing to
-        # continue - it will fail later on.
-        return f
-
-    if args.variable_file is not None:
-        args.variable_file = [fixPath(f) for f in args.variable_file]
-    if args.datacoding_file is not None:
-        args.datacoding_file = [fixPath(f) for f in args.datacoding_file]
-
-    args.type_file       = fixPath(args.type_file)
-    args.processing_file = fixPath(args.processing_file)
-    args.category_file   = fixPath(args.category_file)
-
-
 def _prepareAuxFileNames(args):
     """Sub-function of :func:`parseArgs`. Prepares arguments related to
     the auxillary output files.
