@@ -12,18 +12,24 @@ and for cleaning and processing.
 The following plugin types currently exist:
 
 
-  +-------------------+-------------------------------------------------------+
-  | Plugin type       |                                                       |
-  +-------------------+-------------------------------------------------------|
-  | ``sniffer``       | Return information about the columns in a file        |
-  | ``loader``        | Load data from a file                                 |
-  | ``cleaner``       | Run a cleaning function on a single column            |
-  | ``processor``     | Run a processing function on one or more data columns |
-  | ``metaproc``      | Run a function on a :class:`.Column` ``metadata``     |
-  |                   | value                                                 |
-  | ``formatter``     | Format a column for output                            |
-  | ``exporter``      | Export the processed data set                         |
-  +-------------------+-------------------------------------------------------+
++-------------------+-------------------------------------------------------+
+| Plugin type       |                                                       |
++===================+=======================================================+
+| ``sniffer``       | Return information about the columns in a file        |
++-------------------+-------------------------------------------------------+
+| ``loader``        | Load data from a file                                 |
++-------------------+-------------------------------------------------------+
+| ``cleaner``       | Run a cleaning function on a single column            |
++-------------------+-------------------------------------------------------+
+| ``processor``     | Run a processing function on one or more data columns |
++-------------------+-------------------------------------------------------+
+| ``metaproc``      | Run a function on a :class:`.Column` ``metadata``     |
+|                   | value                                                 |
++-------------------+-------------------------------------------------------+
+| ``formatter``     | Format a column for output                            |
++-------------------+-------------------------------------------------------+
+| ``exporter``      | Export the processed data set                         |
++-------------------+-------------------------------------------------------+
 
 
 To ensure that the ``funpack`` command line help and generated documentation
@@ -53,7 +59,6 @@ form::
 
 
 import importlib.util as imputil
-import os.path        as op
 import functools      as ft
 import                   re
 import                   sys
@@ -61,6 +66,8 @@ import                   logging
 import                   importlib
 import                   collections
 
+import funpack.util   as util
+
 
 log = logging.getLogger(__name__)
 
@@ -77,6 +84,10 @@ PLUGIN_TYPES = ['loader',
 class PluginRegistry:
     """The ``PluginRegistry`` keeps track of, and provides access to all
     registered plugins.
+
+    A singleton ``PluginRegistry`` is created at first import of this module,
+    and module-level aliases for all of its methods are created - see below,
+    after the class definition.
     """
 
     def __init__(self):
@@ -135,16 +146,7 @@ class PluginRegistry:
         plugin functions.
         """
 
-        # If file does not exist, assume
-        # it is a direct reference to a
-        # file in the plugins directory.
-        if not op.exists(filename):
-            if not filename.endswith('.py'):
-                filename = filename + '.py'
-            moddir   = op.dirname(op.abspath(__file__))
-            filename = op.join(moddir, 'plugins', filename)
-
-        filename = op.abspath(filename)
+        filename = util.findPluginFile(filename)
         name     = re.sub('[^a-zA-Z]', '_', filename)
 
         log.debug('Loading custom plugin: %s [%s]', name, filename)
