@@ -9,11 +9,14 @@
 """
 
 
-import itertools         as it
-import                      io
-import                      csv
-import                      logging
-import                      collections
+import itertools as it
+import functools as ft
+import              io
+import              csv
+import              logging
+import              collections
+
+from typing import Sequence
 
 import funpack.util      as util
 import funpack.custom    as custom
@@ -344,6 +347,25 @@ class FileInfo:
         return list(self.__datafiles)
 
 
+    @property
+    @ft.lru_cache()
+    def allColumns(self) -> Sequence[datatable.Column]:
+        """Returns a list containing all columns from all data files. The result
+        is just a concatenation of the lists returned by :meth:`columns` for each
+        data file.
+        """
+        return list(it.chain(*[self.columns(df) for df in self.datafiles]))
+
+
+    @property
+    @ft.lru_cache()
+    def allVariables(self) -> Sequence[int]:
+        """Returns a list containing all variable IDs from all data files.
+        Duplicates are removed, and the IDs are sorted.
+        """
+        return sorted({c.vid for c in self.allColumns})
+
+
     def dialect(self, datafile):
         """Return the CSV dialect type for the given ``datafile``. """
         return self.__dialects[datafile]
