@@ -8,8 +8,8 @@
 <https://en.wikipedia.org/wiki/ICD-10>`_ disease coding hierarcy.
 
 
-The :func:`codeToNumeric` function will take an ICD10 coding, and return
-a numeric variant of it.
+The :func:`toNumeric` function will take an ICD10 coding, and return a numeric
+variant of it.
 
 
 The :func:`storeCodes` function allows sets of ICD10 codes to be stored
@@ -19,6 +19,7 @@ a later stage.
 
 
 import              logging
+import              string
 import itertools as it
 import functools as ft
 
@@ -123,3 +124,30 @@ def saveCodes(fname, hier, fields=None):
 
     df = df[fields]
     df.to_csv(fname, sep='\t', index=False)
+
+
+def toNumeric(code):
+    """Converts an ICD10 alpha-numeric code to a unique integer number.
+
+    This function may be used by the :func:`~.cleaning_functions.codeToNumeric`
+    cleaning function.
+
+    This function is intended to be used with ICD10 codes - if it is used to
+    convert longer strings containing many letters, it may produce integer values
+    that cannot be represented in 64 bits.
+
+    See https://www.webpt.com/blog/understanding-icd-10-code-structure/ for an
+    overview of the ICD10 coding scheme.
+    """
+
+    # construct as a string, then
+    # convert to a number afterwards
+    number  = ''
+    letters = string.ascii_letters
+    digits  = string.digits
+
+    for ch in code:
+        if   ch in letters: number += str(string.ascii_letters.index(ch) + 10)
+        elif ch in digits:  number += ch
+
+    return int(number)
