@@ -78,6 +78,7 @@ def importData(fileinfo,
                mergeStrategy=None,
                indexVisits=False,
                dropNaRows=False,
+               addAuxVars=False,
                njobs=1,
                mgr=None,
                dryrun=False):
@@ -140,6 +141,13 @@ def importData(fileinfo,
     :arg dropNaRows:        If ``True``, rows which do not contain data for any
                             columns are not loaded.
 
+    :arg addAuxVars:        If ``True``, data fields which are referred to in
+                            the processing rules are selected for import if
+                            present in the input file(s) and not already
+                            selected, and . See the ``take`` argument to
+                            :func:`.processing_functions.binariseCategorical`
+                            for an example.
+
     :arg njobs:             Number of processes to use for parallelising tasks.
 
     :arg mgr:               :class:`multiprocessing.Manager` object for
@@ -157,9 +165,17 @@ def importData(fileinfo,
                                loaded from each input file.
     """
 
+    # generate a list of variable IDs to include/exclude,
+    # from variable/category selection/deselection options
     variables, excludevars = filter.restrictVariables(
         cattable, variables, categories, excludeVariables, excludeCategories)
 
+    # make sure auxillary variables are to be imported
+    # (e.g. binariseCategorical(take))
+    if addAuxVars:
+        variables, excludevars = filter.addAuxillaryVariables(
+            fileinfo, proctable, variables, excludevars)
+
     # Figure out which columns to load
     cols, drop = filter.columnsToLoad(fileinfo,
                                       vartable,
