@@ -15,10 +15,11 @@ import              fnmatch
 import              logging
 import              collections
 
-from typing import Sequence, Union
+from typing import Sequence, Union, Optional, Tuple
 
 import pandas as pd
 
+import funpack.fileinfo   as finfo
 import funpack.expression as expression
 import funpack.loadtables as loadtables
 
@@ -38,7 +39,7 @@ def _ispattern(s):
     """Returns ``True`` if ``s`` looks like a ``fnmatch``-style pattern,
     ``False`` otherwise.
     """
-    return any([c in s for c in '*?['])
+    return any(c in s for c in '*?[')
 
 
 def restrictVariables(
@@ -47,8 +48,7 @@ def restrictVariables(
         categories        : Sequence[Union[str, int]] = None,
         excludeVariables  : Sequence[int]             = None,
         excludeCategories : Sequence[Union[str, int]] = None
-) -> Union[None, Sequence[int]]:
-
+) -> Tuple[Optional[Sequence[int]], Optional[Sequence[int]]]:
     """Determines which variables should be loaded (and the order they should
     appear in the output), and which variables should be excluded, from the
     given sequences of ``variables``,  ``categories``, and ``excludeVariables``
@@ -95,6 +95,59 @@ def restrictVariables(
     return variables, exclude
 
 
+def addAuxillaryVariables(fileinfo  : finfo.FileInfo,
+                          proctable : pd.DataFrame,
+                          variables : Sequence[int] = None,
+                          exclude   : Sequence[int] = None
+) -> Tuple[Optional[Sequence[int]], Optional[Sequence[int]]]:
+    """Checks that auxillary variables referred to by processing rules are to
+    be loaded.
+
+    :arg fileinfo:  :class:`.FileInfo` object describing the input
+                    file(s).
+    :arg proctable: Processing table
+    :arg variables: Variables to load, as returnened by
+                    :func:`restrictVariables`
+    :arg exclude:   Variables to exclude, as returnened by
+                    :func:`restrictVariables`
+
+    :returns:       A tuple containing:
+
+                     - a sequence of variables to load, or ``None`` if
+                       all variables should be loaded.
+
+                     - a sequence of variables to exclude, or ``None``
+                       if no variables should be excluded.
+    """
+    if variables is None and exclude is None:
+        return None, None
+
+    if exclude is None:
+        exclude = []
+
+    # each entry in the processing table
+    # is an ordered dictionary of {name :
+    # Process} mappings
+    for procs in proctable['Process']:
+        for proc in procs.values():
+            auxvids = proc.auxillaryVariables()
+
+            for vid in auxvids:
+                # load if not already being loaded,
+                # and if present in input file(s)
+                if vid in exclude:
+                    exclude.remove(vid)
+                if variables is not None and \
+                   vid not in variables  and \
+                   vid in fileinfo.allVariables:
+                    variables.append(vid)
+
+    if len(exclude) == 0:
+        exclude = None
+
+    return variables, exclude
+
+
 def columnsToLoad(fileinfo,
                   vartable,
                   variables,
@@ -319,7 +372,7 @@ def filterSubjects(data,
         if mask is None: mask           = ~exclmask
         else:            mask[exclmask] = 0
 
-    if mask is not None: return data.loc[mask, :]
+    if mask is not None: return data.drop(data.index[~mask])
     else:                return data
 
 
