@@ -60,9 +60,11 @@ def main(argv=None):
     # we can set up logging properly.
     configLogging(args)
 
-    log.info('funpack %s', funpack.__version__)
+    log.info('funpack %s', funpack.version())
     log.info('Date: %s (%s)', date.today(), calendar.day_name[date.weekday()])
     log.info('Command-line arguments %s', ' '.join(argv))
+    for e in args.echo:
+        log.info(e)
     log.debug('Running with the following options')
     for name, val in args.__dict__.items():
         if val is not None:
@@ -208,7 +210,6 @@ def doImport(args, mgr):
                 prependProcess=args.prepend_process,
                 appendProcess=args.append_process)
 
-
     subjects, exprs = args.subject
     if suffix is None: excludeColnames = []
     else:              excludeColnames = [suffix]
@@ -234,6 +235,7 @@ def doImport(args, mgr):
             mergeStrategy=args.merge_strategy,
             indexVisits=args.index_visits,
             dropNaRows=args.drop_na_rows,
+            addAuxVars=args.add_aux_vars,
             njobs=args.num_jobs,
             mgr=mgr,
             dryrun=args.dry_run)
@@ -631,11 +633,16 @@ def configLogging(args):
 
     logging.getLogger('funpack').setLevel(loglevel)
 
-    if args.quiet or args.noisy < 3:
+    if args.noisy < 3:
         warnings.filterwarnings('ignore',  module='pandas')
         warnings.filterwarnings('ignore',  module='numpy')
         warnings.filterwarnings('ignore',  module='tables')
 
+    # print deprecation warnings
+    # at any verbosity level
+    if args.noisy >= 1:
+        warnings.filterwarnings('default', category=DeprecationWarning)
+
     if args.noisy == 1:
         makequiet = ['funpack.expression',
                      'funpack.custom',
