@@ -58,6 +58,8 @@ The following processing functions are defined:
    removeIfRedundant
    binariseCategorical
    expandCompound
+   createDiagnosisColumns
+   removeField
 """
 
 
@@ -377,12 +379,6 @@ def _pairwiseRemoveIfRedundant(dtable, data, corrthres, nathres=None):
 # are not present in the data from the list
 # of vids that are passed in - we do our
 # own check here.
-#
-# Both of the above are ridiculous hacks
-# which are in place because this function,
-# and FUNPACK, used to parallelise things
-# differently, and to preserve backwards
-# compatibility.
 @custom.processor(auxvids=['take'], filterMissing=False)
 def binariseCategorical(dtable,
                         vids,
@@ -430,7 +426,7 @@ def binariseCategorical(dtable,
     ``False``        ``False``           ``'{vid}-{visit}.{instance}_{value}'``
     ``False``        ``True``            ``'{vid}-{visit}.{value}'``
     ``True``         ``False``           ``'{vid}-{value}.{instance}'``
-    ``True``         ``True``            ``'{vid}-0.{value}'``
+    ``True``         ``True``            ``'{vid}-{value}'``
     ================ =================== ======================================
 
     The ``replace`` option controls whether the original un-binarised columns
@@ -480,7 +476,7 @@ def binariseCategorical(dtable,
         (False, False) : '{vid}-{visit}.{instance}_{value}',
         (False, True)  : '{vid}-{visit}.{value}',
         (True,  False) : '{vid}-{value}.{instance}',
-        (True,  True)  : '{vid}-0.{value}',
+        (True,  True)  : '{vid}-{value}',
     }
 
     if nameFormat is None:
@@ -535,14 +531,6 @@ def binariseCategorical(dtable,
 
             for col, val in zip(binarised.T, values):
 
-                # make sure no periods appear
-                # in the resulting column name.
-                # We're assuming here that all
-                # categoricals are integers,
-                # which has not been verified.
-                try:               val = int(val)
-                except ValueError: pass
-
                 fmtargs = {
                     'vid'      : str(int(cols[0].vid)),
                     'visit'    : str(int(cols[0].visit)),
@@ -555,10 +543,19 @@ def binariseCategorical(dtable,
                     index=dtable.index,
                     name=nameFormat.format(**fmtargs))
 
+                # The value is stored on each Column object as
+                # an attribute "binariseCategorical_value".
+                # This may be used by other processing
+                # functions (see e.g. createDiagnosisColumns
+                # with the binarised=True option).  The value
+                # is also stored as "metadata", which is used
+                # by the --description_file cli option - see
+                # funpack.main.generateDescription).
                 colargs = {
-                    'metadata' : val,
-                    'basevid'  : takevid,
-                    'fillval'  : fillval
+                    'metadata'                  : val,
+                    'binariseCategorical_value' : val,
+                    'basevid'                   : takevid,
+                    'fillval'                   : fillval
                 }
 
                 newvids   .append(vid)
@@ -615,3 +612,131 @@ def expandCompound(dtable, vids, nameFormat=None, replace=True):
 
     if replace: return columns, newseries, newvids
     else:       return          newseries, newvids
+
+
+@custom.processor(auxvids=["primvid", "secvid"])
+def createDiagnosisColumns(dtable,
+                           vids,
+                           primvid,
+                           secvid,
+                           replace=True,
+                           primfmt=None,
+                           secfmt=None,
+                           binarised=False):
+    """createDiagnosisColumns(primvid, secvid)
+    Create binary columns for (e.g.) ICD10 codes, denoting them as either primary or secondary.
+
+    This function is intended for use with data fields containing ICD9, ICD10,
+    OPSC3, and OPSC4 diagnosis codes.  The UK Biobank publishes these
+    diagnosis/operative procedure codes twice:
+
+      - The codes are published in a "main" data field containing all codes
+      - The codes are published again in two other data fields, containing
+        separate "primary" and "secondary" codes.
+
+    =====  ===============  ==================  ====================
+    Code   Main data field  Primary data field  Secondary data field
+    =====  ===============  ==================  ====================
+    ICD10  41270            41202               41204
+    ICD9   41271            41203               41205
+    OPSC4  41272            41200               41210
+    OPSC3  41273            41256               41258
+    =====  ===============  ==================  ====================
+
+    For example, this function may be applied to the ICD10 diagnosis codes
+    like so::
+
+        41270 createDiagnosisColumns(41202, 41204)
+
+    When applied to one of the main data fields, (e.g. 41270 - ICD10
+    diagnoses), this function will create two new columns for every unique
+    ICD10 diagnosis code:
+
+     - the first column contains a 1 if the code corresponds to a primary
+       diagnosis (i.e. is also in 41202).
+     - the second column contains a 1 if the code corresponds to a secondary
+       diagnosis (i.e. is also in 41204).
+
+    The ``replace`` option defaults to ``True`` - this causes the primary and
+    secondary code columns to be removed from the data set.
+
+    The ``binarised`` option defaults to ``False``, which causes this function
+    to expect the input columns to be in their raw format, as described in the
+    UKB showcase
+    (e.g. https://biobank.ctsu.ox.ac.uk/crystal/field.cgi?id=41270). The
+    ``binarised`` option can be set to ``True``, which will allow this
+    function to be applied to data fields which have been passed through the
+    :func:`binariseCategorical` function.
+    """  # noqa
+
+    if len(vids) == 0:
+        return
+
+    if len(vids) != 1:
+        raise ValueError('createDiagnosisColumns can only be '
+                         f'applied to one datafield [{vids}]')
+
+    if primfmt is None: primfmt = '{primvid}-{code}.primary'
+    if secfmt  is None: secfmt  = '{secvid}-{code}.secondary'
+
+    # create separate data frames containing
+    # only primary/secondary code columns
+    mainvid  = vids[0]
+    maincols = dtable.columns(mainvid)
+    pricols  = dtable.columns(primvid)
+    seccols  = dtable.columns(secvid)
+    pridf    = dtable[:, [c.name for c in pricols]]
+    secdf    = dtable[:, [c.name for c in seccols]]
+
+    log.debug('Counting unique values across %u columns...', len(maincols))
+
+    # Original data field has already been passed
+    # through binariseCategorical - we have one
+    # input column per unique code (and can get
+    # those codes from the Column objects)
+    if binarised:
+        uniq = [c.binariseCategorical_value for c in maincols]
+        uniq = sorted(pd.unique(uniq))
+    else:
+        uniq = [dtable[:, c.name].dropna() for c in maincols]
+        uniq = sorted(pd.unique(pd.concat(uniq, ignore_index=True)))
+
+    log.debug('Identifying primary/secondary codes [%s = %s + %s]...',
+              mainvid, primvid, secvid)
+    pribin = np.zeros((dtable.shape[0], len(uniq)), dtype=np.uint8)
+    secbin = np.zeros((dtable.shape[0], len(uniq)), dtype=np.uint8)
+
+    for i, code in enumerate(uniq):
+        pribin[:, i] = (pridf == code).any(axis=1)
+        secbin[:, i] = (secdf == code).any(axis=1)
+
+    fmtargs    = {'mainvid' : mainvid,
+                  'primvid' : primvid,
+                  'secvid'  : secvid}
+    pribincols = [primfmt.format(code=code, **fmtargs) for code in uniq]
+    secbincols = [secfmt .format(code=code, **fmtargs) for code in uniq]
+    pribincols = [pd.Series(d, index=dtable.index, name=c)
+                  for d, c in zip(pribin.T, pribincols)]
+    secbincols = [pd.Series(d, index=dtable.index, name=c)
+                  for d, c in zip(secbin.T, secbincols)]
+
+    add     = pribincols + secbincols
+    addvids = [primvid] * len(uniq) + [secvid] * len(uniq)
+    colargs = [{'metadata' : c} for c in uniq] * 2
+
+    if replace: remove = pricols + seccols
+    else:       remove = []
+
+    return remove, add, addvids, colargs
+
+
+@custom.processor()
+def removeField(dtable, vids):
+    """removeField()
+    Remove all columns associated with one or more datafields/variables.
+
+    This function can be used to simply remove columns from the data set. This
+    can be useful if a variable is required for some processing step, but is
+    not needed in the final output file.
+    """
+    return list(it.chain(*[dtable.columns(v) for v in vids]))
