@@ -32,7 +32,7 @@ def main(argv=None):
 
     with tempfile.TemporaryDirectory() as tmpdir:
 
-        create_funpack_entrypoint(op.join(tmpdir, 'funpack'))
+        create_funpack_entrypoint(op.join(tmpdir, 'fmrib_unpack'))
         os.environ['PATH'] = op.pathsep.join((
             os.environ['PATH'], tmpdir))
 
