@@ -100,6 +100,18 @@ def tempdir(root=None, changeto=True):
         shutil.rmtree(testdir)
 
 
+def touch(path):
+    with open(path, 'wt') as f:
+        f.write(path)
+
+
+def mktree(filepaths):
+    for path in filepaths:
+        os.makedirs(op.dirname(path), exist_ok=True)
+        touch(path)
+
+
+
 def gen_test_data(num_vars,
                   num_subjs,
                   out_file,
