@@ -21,6 +21,7 @@ import pandas as pd
 import funpack.loadtables as lt
 import funpack.cleaning as cleaning
 import funpack.custom as custom
+import funpack.icd10 as icd10
 import funpack.cleaning_functions as cfns
 
 import funpack.fileinfo  as fileinfo
@@ -214,20 +215,23 @@ def test_fillMissing():
 
 def test_codeToNumeric():
 
-    hier  = hierarchy.getHierarchyFilePath(name='opcs3')
-    hier  = hierarchy.loadHierarchyFile(hier)
-    codes = list(random.sample(hier.codings, 20)) + ['badcode']
-    exp   = [hier.index(c) for c in codes[:-1]] + [np.nan]
+    hier     = hierarchy.getHierarchyFilePath(name='opcs3')
+    hier     = hierarchy.loadHierarchyFile(hier)
+    codes    = list(random.sample(hier.codings, 20)) + ['badcode']
+    expnode  = [hier .index(    c) for c in codes[:-1]] + [np.nan]
+    expalpha = [icd10.toNumeric(c) for c in codes]
 
     with tempdir():
         with open('data.txt', 'wt') as f:
-            f.write('eid\t1-0.0\n')
+            f.write('eid\t1-0.0\t2-0.0\n')
             for i, c in enumerate(codes, 1):
-                f.write('{}\t{}\n'.format(i, c))
+                f.write('{}\t{}\t{}\n'.format(i, c, c))
 
-        vartable, proctable, cattable, _ = gen_tables([1], vtypes={1:'text'})
+        vartable, proctable, cattable, _ = gen_tables(
+            [1, 2], vtypes={1 : 'text', 2 : 'text'})
 
         vartable.loc[1, 'DataCoding'] = hierarchy.HIERARCHY_DATA_NAMES['opcs3']
+        vartable.loc[2, 'DataCoding'] = hierarchy.HIERARCHY_DATA_NAMES['opcs3']
 
         finfo = fileinfo.FileInfo('data.txt')
         dt, _ = importing.importData(finfo,
@@ -235,15 +239,20 @@ def test_codeToNumeric():
                                      proctable,
                                      cattable)
         cfns.codeToNumeric(dt, 1)
+        cfns.codeToNumeric(dt, 2, scheme='alpha')
 
-        got = dt[:, '1-0.0']
-        exp = pd.Series(exp, name='1-0.0', index=got.index)
+        got1 = dt[:, '1-0.0']
+        got2 = dt[:, '2-0.0']
+        exp1 = pd.Series(expnode,  name='1-0.0', index=got1.index)
+        exp2 = pd.Series(expalpha, name='2-0.0', index=got2.index)
 
-        gotna = pd.isna(got)
-        expna = pd.isna(exp)
+        gotna = pd.isna(got1)
+        expna = pd.isna(exp1)
+
+        assert np.all(got1[~gotna] == exp1[~expna])
+        assert np.all(got2         == exp2)
+        assert np.all(gotna        == expna)
 
-        assert np.all(got[~gotna] == exp[~expna])
-        assert np.all(gotna       == expna)
         dt = None
 
 
