@@ -574,7 +574,7 @@ def test_importData_dropNaRows():
         assert list(loaded.index) == [1, 3, 4, 5, 6, 8, 10]
 
 
-def test_importData_duplicate_columns():
+def test_importData_duplicate_columns_rename():
 
     data       = np.random.randint(1, 100, (10, 3))
     data[:, 0] = np.arange(1, 10 + 1)
@@ -600,9 +600,8 @@ def test_importData_duplicate_columns():
         assert (dtable[:, :] == data[:, 1:]).all().all()
 
 
-def test_importData_duplicate_columns_multiple_files():
-    """
-    """
+def test_importData_duplicate_columns_multiple_files_rename():
+
     data       = np.random.randint(1, 100, (10, 5))
     data[:, 0] = np.arange(1, 10 + 1)
     colnames1  = ['eid'] + ['1-0.0', '2-0.0']
@@ -633,3 +632,74 @@ def test_importData_duplicate_columns_multiple_files():
         assert names     == ['1-0.0', '2-0.0', '2-0.0.1', '3-0.0']
         assert orignames == ['1-0.0', '2-0.0', '2-0.0',   '3-0.0']
         assert (dtable[:, names] == data[:, 1:]).all().all()
+
+
+def test_importData_duplicate_columns_remove():
+
+    data       = np.random.randint(1, 100, (10, 6))
+    data[:, 0] = np.arange(1, 10 + 1)
+    colnames   = ['eid'] + ['1-0.0', '1-0.0', '2-0.0', '3-0.0', '3-0.0']
+
+    vartable, proctable, cattable = gen_tables([1])[:3]
+
+    custom.registerBuiltIns()
+
+    with tempdir():
+        with open('data.txt', 'wt') as f:
+            f.write('\t'.join(colnames) + '\n')
+            np.savetxt(f, data, fmt='%i', delimiter='\t')
+
+        finfo     = fileinfo.FileInfo('data.txt',
+                                      renameDuplicates=True,
+                                      renameSuffix='.REMOVE')
+        dtable, _ = importing.importData(finfo,
+                                         vartable,
+                                         proctable,
+                                         cattable,
+                                         excludeColnames=['.REMOVE'])
+
+        cols = dtable.dataColumns
+
+        assert dtable.variables           == [0, 1, 2, 3]
+        assert [c.name     for c in cols] == ['1-0.0', '2-0.0', '3-0.0']
+        assert [c.origname for c in cols] == ['1-0.0', '2-0.0', '3-0.0']
+        assert (dtable[:, :] == data[:, [1, 3, 4]]).all().all()
+
+
+def test_importData_duplicate_columns_multiple_files_remove():
+
+    data       = np.random.randint(1, 100, (10, 8))
+    data[:, 0] = np.arange(1, 10 + 1)
+    colnames1  = ['eid'] + ['1-0.0', '2-0.0', '2-0.0']
+    colnames2  = ['eid'] + ['2-0.0', '3-0.0', '3-0.0', '4-0.0']
+
+    vartable, proctable, cattable = gen_tables([1, 2, 3])[:3]
+
+    custom.registerBuiltIns()
+
+    with tempdir():
+        with open('data1.txt', 'wt') as f:
+            f.write('\t'.join(colnames1) + '\n')
+            np.savetxt(f, data[:, [0, 1, 2, 3]], fmt='%i', delimiter='\t')
+
+        with open('data2.txt', 'wt') as f:
+            f.write('\t'.join(colnames2) + '\n')
+            np.savetxt(f, data[:, [0, 4, 5, 6, 7]], fmt='%i', delimiter='\t')
+
+        finfo     = fileinfo.FileInfo(['data1.txt', 'data2.txt'],
+                                      renameDuplicates=True,
+                                      renameSuffix='.REMOVE')
+        dtable, _ = importing.importData(finfo,
+                                         vartable,
+                                         proctable,
+                                         cattable,
+                                         excludeColnames=['.REMOVE'])
+
+        cols      = dtable.dataColumns
+        names     = sorted([c.name     for c in cols])
+        orignames = sorted([c.origname for c in cols])
+
+        assert dtable.variables  == [0, 1, 2, 3, 4]
+        assert names             == ['1-0.0', '2-0.0', '3-0.0', '4-0.0']
+        assert orignames         == ['1-0.0', '2-0.0', '3-0.0', '4-0.0']
+        assert (dtable[:, names] == data[:, [1, 2, 5, 7]]).all().all()
