@@ -15,8 +15,9 @@ import funpack.importing.filter as filter
 
 from funpack.datatable import Column
 import funpack.fileinfo       as fileinfo
+import funpack.processing     as processing
 from . import (gen_DataTable, gen_DataTableFromDataFrame,
-               tempdir, gen_tables, gen_test_data)
+               tempdir, gen_tables, gen_test_data, clear_plugins)
 
 
 def test_columnsToLoad():
@@ -197,3 +198,43 @@ def test_filter_subjects_column_not_present():
 
     assert (got1 == df).all().all()
     assert (got2 == df).all().all()
+
+
+@clear_plugins
+def test_addAuxillaryVariables():
+    data = tw.dedent("""
+    eid,1-0.0,2-0.0,3-0.0
+    1,10,20,30
+    2,11,21,31
+    3,12,22,32
+    4,13,23,33
+    """).strip()
+
+    proctable = pd.DataFrame({
+        'ID'       : [0],
+        'Variable' : [['vids', [1]]],
+        'Process'  : [{'binariseCategorical' :
+                      processing.Process('processor',
+                                         'binariseCategorical',
+                                         (),
+                                         dict(take=[2]),
+                                         '')}]})
+
+    with tempdir():
+
+        with open('data.txt', 'wt') as f:
+            f.write(data)
+        finfo = fileinfo.FileInfo('data.txt')
+
+        assert filter.addAuxillaryVariables(
+            finfo, proctable, None, None) == (None, None)
+        assert filter.addAuxillaryVariables(
+            finfo, proctable, [1, 2, 3], None) == ([1, 2, 3], None)
+        assert filter.addAuxillaryVariables(
+            finfo, proctable, [1, 3], None) == ([1, 3, 2], None)
+        assert filter.addAuxillaryVariables(
+            finfo, proctable, [1, 2, 3], [2]) == ([1, 2, 3], None)
+        assert filter.addAuxillaryVariables(
+            finfo, proctable, [1, 3], [2]) == ([1, 3, 2], None)
+        assert filter.addAuxillaryVariables(
+            finfo, proctable, [1, 3], [2, 3]) == ([1, 3, 2], [3])
