@@ -24,16 +24,10 @@ from . import tempdir, clear_plugins, patch_base_tables
 
 def _prepare_variableTable(tdir, idxcol=0):
 
-    datadata = [['eid',       '1',    '2',    '3'],
-                ['1-0.0',    '10',   '20',   '30'],
-                ['2-0.0',   '100',  '200',  '300'],
-                ['5-0.0',   '500',  '600',  '700'],
-                ['6-0.0',  '1000', '1100', '1200'],
-                ['99-0.0',   '99',   '99',   '99']]
-    datadata = [['eid',   '1-0.0',  '2-0.0',  '5-0.0',  '6-0.0',  '99-0.0'],
-                [  '1',   '10',     '100',    '500',    '1000',   '99'],
-                [  '2',   '20',     '200',    '600',    '1100',   '99'],
-                [  '3',   '30',     '300',    '700',    '1200',   '99']]
+    datadata = [['eid',   '1-0.0',  '2-0.0',  '5-0.0',  '6-0.0',  '7-0.0', '99-0.0'],
+                [  '1',   '10',     '100',    '500',    '1000',   'aa',    '99'],
+                [  '2',   '20',     '200',    '600',    '1100',   'bb',    '99'],
+                [  '3',   '30',     '300',    '700',    '1200',   'cc',    '99']]
 
     if idxcol != 0:
         for row in datadata:
@@ -48,6 +42,7 @@ def _prepare_variableTable(tdir, idxcol=0):
     4\tInteger\tvar 4\t\t\t\t\t\t\t
     5\tDate\tvar 5\t\t\t\t\t\t\t
     6\tTime\tvar 6\t\t\t\t\t\t\t
+    7\tText\tvar 7\t\t\t\t\t\t\t
     """).strip()
 
     dcdata = textwrap.dedent("""
@@ -131,8 +126,8 @@ def test_loadTables():
     assert unknowns[0].vid == 99
 
     # Test a selection from each table
-    expvids = [1, 2, 5, 6, 99]
-    expdcs  = [100, 200, None, None, None]
+    expvids = [1, 2, 5, 6, 7, 99]
+    expdcs  = [100, 200, None, None, None, None]
     dcs     = [None if pd.isna(d) else d for d in vartable['DataCoding']]
 
     assert list(vartable.index) == expvids
@@ -161,18 +156,19 @@ def test_loadVariableTable_standard():
         vartable, unk, unp = loadtables.loadVariableTable(
             finfo, [fvars], [fdcs], ftypes)
 
-    expvids       = [1, 2, 5, 6, 99]
+    expvids       = [1, 2, 5, 6, 7, 99]
     exptypes      = [util.CTYPES.integer, util.CTYPES.continuous,
-                     util.CTYPES.date, util.CTYPES.time, util.CTYPES.unknown]
-    expdescs      = ['var 1', 'var 2', 'var 5', 'var 6', '99-0.0']
-    expdcs        = [100, 200, None, None, None]
-    expnavals     = [[1, 2, 3], [500, 600], [], [], []]
-    exprawlevels  = [[10, 20], [20, 21, 22], [], [], []]
-    expnewlevels  = [[100, 200], [30, 31, 32], [], [], []]
-    expparentvals = [[100], [], [], [], []]
-    expchildvals  = [[123], [], [], [], []]
+                     util.CTYPES.date, util.CTYPES.time, util.CTYPES.text,
+                     util.CTYPES.unknown]
+    expdescs      = ['var 1', 'var 2', 'var 5', 'var 6', 'var 7', '99-0.0']
+    expdcs        = [100, 200, None, None, None, None]
+    expnavals     = [[1, 2, 3], [500, 600], [], [], [], []]
+    exprawlevels  = [[10, 20], [20, 21, 22], [], [], [], []]
+    expnewlevels  = [[100, 200], [30, 31, 32], [], [], [], []]
+    expparentvals = [[100], [], [], [], [], []]
+    expchildvals  = [[123], [], [], [], [], []]
     expcleans     = [['keepVisits', 'makeNa'],
-                     ['remove', 'keepVisits', 'makeNa'], [], [], []]
+                     ['remove', 'keepVisits', 'makeNa'], [], [], [], []]
 
     assert len(unk)   == 1
     assert unk[0].vid == 99
@@ -214,8 +210,8 @@ def test_loadVariableTable_indexes():
         vartable, unk, unp = loadtables.loadVariableTable(
             finfo, [fvars], [fdcs], ftypes)
 
-    expvids  = [1, 2, 5, 6, 99]
-    expdescs = ['var 1', 'var 2', 'var 5', 'var 6', '99-0.0']
+    expvids  = [1, 2, 5, 6, 7, 99]
+    expdescs = ['var 1', 'var 2', 'var 5', 'var 6', 'var 7', '99-0.0']
 
     assert len(unk)   == 1
     assert unk[0].vid == 99
@@ -251,17 +247,18 @@ def test_loadVariableTable_clean():
 
     pp_expcleans       = [['fillMissing'],
                           ['remove', 'keepVisits', 'makeNa'],
-                          [], [], []]
+                          [], [], [], []]
     tp_expcleans       = [['keepVisits', 'makeNa'],
                            ['remove', 'keepVisits', 'fillMissing'],
-                           [], [], []]
+                           [], [], [], []]
     pp_tp_expcleans    = [['fillMissing'],
                            ['remove', 'keepVisits', 'fillMissing'],
-                           [], [], []]
+                           [], [], [], []]
     pp_tp_gp_expcleans = [['fillMissing', 'codeToNumeric'],
                           ['remove', 'keepVisits', 'fillMissing', 'codeToNumeric'],
                           ['codeToNumeric'],
                           ['codeToNumeric'],
+                          ['codeToNumeric'],
                           ['codeToNumeric']]
     pp_cleans          = [[] if pd.isna(p) else list(p.keys())
                            for p in ppvt['Clean']]
@@ -288,12 +285,15 @@ def test_loadVariableTable_naValues():
 
         vartable, _, _ = loadtables.loadVariableTable(
             finfo, [fvars], [fdcs], ftypes,
-            naValues={2   : [10, 20, 30],
-                      99  : [10, 11, 12],
-                      111 : [ 1,  2,  3]})
+            naValues={2   : '10,20,30',
+                      7   : 'a,b,c',
+                      99  : '10,11,12',
+                      111 : '1,2,3'})
 
-    expvids   = [1, 2, 5, 6, 99]
-    expnavals = [[1, 2, 3], [10, 20, 30], [], [], [10, 11, 12]]
+    # 99 has unknown type, so it is left as string
+    expvids   = [1, 2, 5, 6, 7, 99]
+    expnavals = [[1, 2, 3], [10, 20, 30], [], [], ['a', 'b', 'c'],
+                 ['10', '11', '12']]
 
     navals    = [list(v) if isinstance(v, np.ndarray) else []
                  for v in vartable['NAValues']]
@@ -312,13 +312,16 @@ def test_loadVariableTable_recoding():
 
         vartable, _, _ = loadtables.loadVariableTable(
             finfo, [fvars], [fdcs], ftypes,
-            recoding={2   : ([1, 2, 3],    [10, 20, 30]),
-                      99  : ([40, 50],     [400, 500]),
-                      111 : ([ 1,  2,  3], [100, 200, 300])})
+            recoding={2   : ('1,2,3',  '10,20,30'),
+                      7   : ('a,b,c',  'A,B,C'),
+                      99  : ('40,50',  '400,500'),
+                      111 : ('1, 2,3', '100,200,300')})
 
-    expvids      = [1, 2, 5, 6, 99]
-    exprawlevels = [[10, 20],   [1, 2, 3],    [], [], [40, 50]]
-    expnewlevels = [[100, 200], [10, 20, 30], [], [], [400, 500]]
+    expvids      = [1, 2, 5, 6, 7, 99]
+    exprawlevels = [[10, 20],   [1, 2, 3],    [], [], ['a', 'b', 'c'],
+                    ['40',  '50']]
+    expnewlevels = [[100, 200], [10, 20, 30], [], [], ['A', 'B', 'C'],
+                    ['400', '500']]
 
     rawlevels = [list(v) if isinstance(v, np.ndarray) else []
                  for v in vartable['RawLevels']]
@@ -339,17 +342,18 @@ def test_loadVariableTable_childValues():
         finfo, fvars, fdcs, ftypes = _prepare_variableTable(td)
 
         childValues = {
-            1   : ('v2 != 7', [12345]),
-            99  : ('v5  < 7', [54321]),
-            111 : ('v1 == 6', [55555])}
+            1   : ('v2 !=  7',   '12345'),
+            7   : ('v99 >= 34',  'ABC'),
+            99  : ('v5  <  7',   '54321'),
+            111 : ('v1 ==  6',   '55555')}
 
         vartable, _, _ = loadtables.loadVariableTable(
             finfo, [fvars], [fdcs], ftypes,
             childValues=childValues)
 
-    expvids       = [1, 2, 5, 6, 99]
-    expparentvals = [[2],     [], [], [], [5]]
-    expchildvals  = [[12345], [], [], [], [54321]]
+    expvids       = [1, 2, 5, 6, 7, 99]
+    expparentvals = [[2],     [], [], [], [99],    [5]]
+    expchildvals  = [[12345], [], [], [], ['ABC'], ['54321']]
 
     parentvals = [[]   if pd.isna(exps)
                   else list(it.chain(*[e.variables for e in exps]))
