@@ -18,6 +18,7 @@ import           pytest
 import funpack.processing as processing
 import funpack.importing  as importing
 import funpack.loadtables as loadtables
+import funpack.fileinfo   as fileinfo
 import funpack.custom     as custom
 import funpack.util       as util
 
@@ -61,7 +62,8 @@ def test_processData():
         df.index.name = 'eid'
         df.to_csv('data.txt')
 
-        dtable, _ = importing.importData('data.txt',
+        finfo     = fileinfo.FileInfo('data.txt')
+        dtable, _ = importing.importData(finfo,
                                          vartable,
                                          proctable,
                                          cattable,
@@ -74,7 +76,8 @@ def test_processData():
         processing.processData(dtable)
         assert [c.name for c in dtable.dataColumns] == ['2-0.0']
 
-        dtable, _ = importing.importData('data.txt',
+        finfo     = fileinfo.FileInfo('data.txt')
+        dtable, _ = importing.importData(finfo,
                                          vartable,
                                          proctable,
                                          cattable,
@@ -287,7 +290,8 @@ def test_processData_variable_types():
 
         proctable = loadtables.loadProcessingTable('processing.tsv')
         vartable, _, cattable = gen_tables(range(1, 7))[:3]
-        dtable, _ = importing.importData('data.tsv',
+        finfo     = fileinfo.FileInfo('data.tsv')
+        dtable, _ = importing.importData(finfo,
                                          vartable,
                                          proctable,
                                          cattable)
@@ -372,7 +376,8 @@ def test_processData_returnValues():
 
         proctable = loadtables.loadProcessingTable('processing.tsv')
         vartable, _, cattable = gen_tables(range(1, 16))[:3]
-        dtable, _ = importing.importData('data.tsv',
+        finfo     = fileinfo.FileInfo('data.tsv')
+        dtable, _ = importing.importData(finfo,
                                          vartable,
                                          proctable,
                                          cattable)
@@ -424,7 +429,8 @@ def test_processData_metadata():
 
         proctable = loadtables.loadProcessingTable('processing.tsv')
         vartable, _, cattable = gen_tables([1, 2])[:3]
-        dtable, _ = importing.importData('data.tsv',
+        finfo     = fileinfo.FileInfo('data.tsv')
+        dtable, _ = importing.importData(finfo,
                                          vartable,
                                          proctable,
                                          cattable)
@@ -483,7 +489,7 @@ def test_processData_existing_column():
 
     processing.processData(dt)
 
-    assert np.all(dt.vartable.index)       == [1]
+    assert np.all(dt.vartable.index        == [1])
     assert [c.name for c in dt.allColumns] == ['eid', '1-0.0']
     assert dt.vartable.at[1, 'Type'] == util.CTYPES.categorical_single
     assert dt.vartable.at[1, 'Description'] == 'Super cool'
@@ -516,7 +522,8 @@ def test_processData_parallel():
 
         proctable = loadtables.loadProcessingTable('processing.tsv')
         vartable, _, cattable = gen_tables((1, 2, 3))[:3]
-        dtable, _ = importing.importData('data.tsv',
+        finfo     = fileinfo.FileInfo('data.tsv')
+        dtable, _ = importing.importData(finfo,
                                          vartable,
                                          proctable,
                                          cattable)
@@ -551,7 +558,8 @@ def test_processData_broadcast():
 
         proctable = loadtables.loadProcessingTable('processing.tsv')
         vartable, _, cattable = gen_tables((1, 2, 3))[:3]
-        dtable, _ = importing.importData('data.tsv',
+        finfo     = fileinfo.FileInfo('data.tsv')
+        dtable, _ = importing.importData(finfo,
                                          vartable,
                                          proctable,
                                          cattable)
@@ -588,7 +596,8 @@ def test_processing_auxillaryVariables():
 
         proctable = loadtables.loadProcessingTable('processing.tsv')
         vartable, _, cattable = gen_tables((1, 2, 3, 4))[:3]
-        dtable, _ = importing.importData('data.tsv',
+        finfo     = fileinfo.FileInfo('data.tsv')
+        dtable, _ = importing.importData(finfo,
                                          vartable,
                                          proctable,
                                          cattable)
@@ -627,7 +636,8 @@ def test_processing_auxillaryVariables_parallel():
 
         proctable = loadtables.loadProcessingTable('processing.tsv')
         vartable, _, cattable = gen_tables((1, 2, 3, 4))[:3]
-        dtable, _ = importing.importData('data.tsv',
+        finfo     = fileinfo.FileInfo('data.tsv')
+        dtable, _ = importing.importData(finfo,
                                          vartable,
                                          proctable,
                                          cattable,
@@ -665,7 +675,8 @@ def test_processing_broadcast_auxillaryVariables():
 
         proctable = loadtables.loadProcessingTable('processing.tsv')
         vartable, _, cattable = gen_tables((1, 2, 3, 4, 5, 6))[:3]
-        dtable, _ = importing.importData('data.tsv',
+        finfo     = fileinfo.FileInfo('data.tsv')
+        dtable, _ = importing.importData(finfo,
                                          vartable,
                                          proctable,
                                          cattable)
@@ -709,7 +720,8 @@ def test_processing_broadcast_missing_variables():
 
         proctable = loadtables.loadProcessingTable('processing.tsv')
         vartable, _, cattable = gen_tables((2, 3, 4, 5, 6))[:3]
-        dtable, _ = importing.importData('data.tsv',
+        finfo     = fileinfo.FileInfo('data.tsv')
+        dtable, _ = importing.importData(finfo,
                                          vartable,
                                          proctable,
                                          cattable)
@@ -753,7 +765,8 @@ def test_processing_column_attrs():
 
         proctable = loadtables.loadProcessingTable('processing.tsv')
         vartable, _, cattable = gen_tables((1,))[:3]
-        dtable, _ = importing.importData('data.tsv',
+        finfo     = fileinfo.FileInfo('data.tsv')
+        dtable, _ = importing.importData(finfo,
                                          vartable,
                                          proctable,
                                          cattable)
