@@ -223,6 +223,18 @@ def test_isSparse_mincat():
     assert core.isSparse(data, None, mincat=0.4, abscat=False) == \
         (True, 'mincat', 20)
 
+# https://git.fmrib.ox.ac.uk/fsl/funpack/-/merge_requests/81
+def test_isSparse_mincat_maxcat_empty():
+
+    data = np.full(10, np.nan, dtype=np.float32)
+    data = pd.Series(data)
+
+    result = core.isSparse(data, util.CTYPES.categorical_single, mincat=2)
+    assert result == (True, 'mincat', 0)
+
+    result = core.isSparse(data, util.CTYPES.categorical_single, maxcat=2)
+    assert result == (True, 'maxcat', 0)
+
 
 def test_isSparse_non_numeric():
 
@@ -337,10 +349,12 @@ def wrapped_pairwiseRedundantColumns(df, corrthres):
     return core.pairwiseRedundantColumns(df, colpairs, corrthres)
 
 def test_pairwiseRedundantColumns():
-    _test_redundantColumns(wrapped_pairwiseRedundantColumns)
+    with np.errstate(divide='ignore'):
+        _test_redundantColumns(wrapped_pairwiseRedundantColumns)
 
 def test_matrixRedundantColumns():
-    _test_redundantColumns(core.matrixRedundantColumns)
+    with np.errstate(divide='ignore'):
+        _test_redundantColumns(core.matrixRedundantColumns)
 
 def _test_redundantColumns(rcfunc):
 
@@ -352,62 +366,73 @@ def _test_redundantColumns(rcfunc):
     data = pd.DataFrame({0 : pd.Series(series1), 1 : pd.Series(series2)})
 
     assert np.all(rcfunc(data, corr * 1.01) == [])
-    assert np.all(rcfunc(data, corr * 0.99) == [1])
+    # later (naturally ordered) columns will be
+    # the ones flagged as redundant, if they
+    # have the same number of missing values
+    assert np.all(rcfunc(data, corr * 0.99) == [(1, 0)])
 
     # the column with more missing values
     # should be the one flagged as redundant
     data.loc[0, 0] = np.nan
     corr = pd.Series(data[0]).corr(data[1])
     assert np.all(rcfunc(data, corr * 1.01) == [])
-    assert np.all(rcfunc(data, corr * 0.99) == [0])
+    assert np.all(rcfunc(data, corr * 0.99) == [(0, 1)])
     data.loc[0:2, 1] = np.nan
     corr = pd.Series(data[0]).corr(data[1])
     assert np.all(rcfunc(data, corr * 1.01) == [])
-    assert np.all(rcfunc(data, corr * 0.99) == [1])
+    assert np.all(rcfunc(data, corr * 0.99) == [(1, 0)])
 
 
 def test_pairwiseRedundantColumns_associative():
-    _test_redundantColumns_associative(wrapped_pairwiseRedundantColumns)
+    with np.errstate(divide='ignore'):
+        _test_redundantColumns_associative(wrapped_pairwiseRedundantColumns)
 
 def test_matrixRedundantColumns_associative():
-    _test_redundantColumns_associative(core.matrixRedundantColumns)
+    with np.errstate(divide='ignore'):
+        _test_redundantColumns_associative(core.matrixRedundantColumns)
 
 def _test_redundantColumns_associative(rcfunc):
 
-    seed = np.random.randint(2 ** 31)
-    np.random.seed(seed)
-    print('Seed for random number generator:', seed)
+    # Three columns a, b, and c, where
+    # corr(a,b) > corr(a,c) > corr(b,c)
+    cov = np.array([[10,  8,  4],
+                    [ 8, 10,  2],
+                    [ 4,  2, 10]])
+    a, b, c = np.random.multivariate_normal([1, 1, 1], cov, 100).T
 
-    a        = np.random.randint(1, 100, 100).astype(np.float32)
-    b        = np.copy(a)
-    c        = np.copy(a)
-
-    # assuminng that this is enough to guarantee
-    # corr(a,b) > corr(a,c) < corr(b,c)
-    b[::25]  = np.random.randint(1, 100, 4)
-    c[::4]   = np.random.randint(1, 100, 25)
-
-    # make sure that a is always selected over b
-    # and b is always selected over c
+    # make sure that a is always selected
+    # over b and b is always selected over
+    # c, i.e. nans(a) < nans(b) < nans(c)
     b[-1]    = np.nan
     c[-2:]   = np.nan
     df       = pd.DataFrame(np.array([a, b, c]).T, columns=['a', 'b', 'c'])
 
     corrmat  = df.corr()
     abthres  = corrmat.loc['a', 'b']
+    acthres  = corrmat.loc['a', 'c']
     bcthres  = corrmat.loc['b', 'c']
 
-    # result should be the same regardless of column order
-    for colorder in it.permutations('abc', 3):
+    colorder = 'abc'
+    if True: # for colorder in it.permutations('abc', 3):
         df = df[list(colorder)]
 
         a = colorder.index('a')
         b = colorder.index('b')
         c = colorder.index('c')
 
-        assert        np.all(rcfunc(df,  abthres * 1.05)         == [])
-        assert        np.all(rcfunc(df, (abthres + bcthres) / 2) == [b])
-        assert np.all(sorted(rcfunc(df,  bcthres * 0.95))        == sorted([b, c]))
+        # threshold higher than all corrlations
+        assert np.all(rcfunc(df,  abthres * 1.05) == [])
+        # threshold lower than a+b, higher than others
+        assert np.all(rcfunc(df, (abthres + acthres) / 2) == [(b, a)])
+        # threshold lower than a+b, a+c, higher than b+c
+        assert np.all(rcfunc(df, (acthres + bcthres) / 2) == [(b, a), (c, a)])
+        # threshold lower than all - both b and c
+        # should be redundant. Depending on column
+        # order, c will be redundant w.r.t. a or
+        # to b
+        if a < b: exp = [(b, a), (c, a)]
+        else:     exp = [(b, a), (c, b)]
+        assert np.all(sorted(rcfunc(df,  bcthres * 0.95)) == sorted(exp))
 
 
 # test that pairwise/matrix implementations produce same result
@@ -431,23 +456,26 @@ def test_redundantColumns_na():
         nathres   = np.abs(nacorr[~np.isclose(nacorr, 1)]).mean()
         corrthres = np.abs(dcorr[ ~np.isclose(dcorr,  1)]).mean()
 
-        nacorr   = core.naCorrelation(pd.isna(df), nathres)
-        colpairs = np.where(np.triu(nacorr, k=1))
-        colpairs = np.vstack(colpairs).T
+        with np.errstate(divide='ignore'):
+            nacorr   = core.naCorrelation(pd.isna(df), nathres)
+            colpairs = np.where(np.triu(nacorr, k=1))
+            colpairs = np.vstack(colpairs).T
 
-        pairwise = core.pairwiseRedundantColumns(df, colpairs, corrthres)
-        matrix   = core.matrixRedundantColumns(  df, corrthres, nathres)
+            pairwise = core.pairwiseRedundantColumns(df, colpairs, corrthres)
+            matrix   = core.matrixRedundantColumns(  df, corrthres, nathres)
 
         nacounts = np.isnan(data).sum(axis=0)
         corrmask = nacorr & (np.abs(dcorr) > corrthres)
         colpairs = np.where(np.triu(corrmask, k=1))
         colpairs = np.vstack(colpairs).T
-        exp = []
+        exp = {}
         for ci, cj in colpairs:
-            if nacounts[ci] > nacounts[cj]: exp.append(ci)
-            else:                           exp.append(cj)
+            if nacounts[ci] > nacounts[cj]: drop, keep = ci, cj
+            else:                           drop, keep = cj, ci
 
-        exp = np.unique(exp)
+            if drop not in exp:
+                exp[drop] = keep
+        exp = list(exp.items())
 
         assert np.all(sorted(exp)      == sorted(matrix))
         assert np.all(sorted(pairwise) == sorted(matrix))
@@ -475,12 +503,12 @@ def test_redundantColumns_constant_allna():
     data[9, 1] = np.nan
     df         = pd.DataFrame(data.T)
 
-    nacorr   = core.naCorrelation(pd.isna(df), 0.1)
-    colpairs = np.where(np.triu(nacorr, k=1))
-    colpairs = np.vstack(colpairs).T
-
-    pairwise = core.pairwiseRedundantColumns(df, colpairs, 0.2)
-    matrix   = core.matrixRedundantColumns(  df, 0.2, 0.1)
+    with np.errstate(divide='ignore'):
+        nacorr   = core.naCorrelation(pd.isna(df), 0.1)
+        colpairs = np.where(np.triu(nacorr, k=1))
+        colpairs = np.vstack(colpairs).T
+        pairwise = core.pairwiseRedundantColumns(df, colpairs, 0.2)
+        matrix   = core.matrixRedundantColumns(  df, 0.2, 0.1)
 
     pairwise = np.array(sorted(pairwise))
     matrix   = np.array(sorted(matrix))
@@ -657,6 +685,18 @@ def test_binariseCategorical_datetime():
     assert np.all(expdata[~expnan]     == parbindata[~expnan])
 
 
+# https://git.fmrib.ox.ac.uk/fsl/funpack/-/merge_requests/81
+def test_binariseCategorical_empty():
+
+    data = np.full(10, np.nan, dtype=np.float32)
+    data = pd.DataFrame(data)
+
+    columns, values = core.binariseCategorical(data)
+
+    assert columns.shape[1] == 0
+    assert len(values)      == 0
+
+
 def test_expandCompound():
 
     data = []
