@@ -8,6 +8,7 @@
 import string
 import random
 import textwrap as tw
+import itertools as it
 import multiprocessing as mp
 
 import io
@@ -21,6 +22,7 @@ from pandas.testing import assert_frame_equal
 
 import funpack.importing            as importing
 import funpack.fileinfo             as fileinfo
+import funpack.hierarchy            as hierarchy
 import funpack.util                 as util
 import funpack.processing_functions as pfns
 
@@ -219,9 +221,13 @@ def test_removeIfRedundant_skipUnknowns():
 
 
 @patch_logging
-def test_binariseCateorical():
+def test_binariseCategorical():
 
-    data = np.random.randint(1, 10, (50, 14))
+    # internally, funpack stores integers as float32,
+    # so it can use nan to represent missing. This
+    # affects column name generation (e.g. 1-0.1.0,
+    # rather than 1-0.1)
+    data = np.random.randint(1, 10, (50, 14)).astype(np.float32)
     data[:, 0] = np.arange(1, 51)
     cols = ['eid',
             '1-0.0', '1-1.0',
@@ -234,7 +240,7 @@ def test_binariseCateorical():
     didxs = list(range(1, 14))
 
     with tempdir():
-        np.savetxt('data.txt', data, delimiter=',', header=','.join(cols))
+        np.savetxt('data.txt', data, fmt='%i', delimiter=',', header=','.join(cols))
         vartable, proctable, cattable = gen_tables(range(1, 13))[:3]
         finfo = fileinfo.FileInfo('data.txt')
         dt, _ = importing.importData(finfo, vartable, proctable, cattable)
@@ -260,7 +266,7 @@ def test_binariseCateorical():
                 offset += 1
 
                 assert addvids[i] == int(cols[didx].split('-')[0])
-                assert add[i].name == '{}.{}'.format(cols[didx], int(u))
+                assert add[i].name == '{}.{}'.format(cols[didx], u)
                 assert (add[i] == exp).all()
                 assert kwargs[i]['metadata'] == u
 
@@ -285,7 +291,7 @@ def test_binariseCateorical():
                     offset += 1
                     got = add[i]
                     assert addvids[i] == vid
-                    assert got.name == '{}.{}.{}'.format(vid, instance, int(u))
+                    assert got.name == '{}.{}.{}'.format(vid, instance, u)
                     assert (got == exp).all()
                     assert kwargs[i]['metadata'] == u
         assert names == [r.name for r in remove]
@@ -311,7 +317,7 @@ def test_binariseCateorical():
                     offset += 1
                     got = add[i]
                     assert addvids[i] == vid
-                    assert got.name == '{}.{}.{}'.format(vid, visit, int(u))
+                    assert got.name == '{}.{}.{}'.format(vid, visit, u)
                     assert (got == exp).all()
                     assert kwargs[i]['metadata'] == u
         assert names == [r.name for r in remove]
@@ -336,7 +342,7 @@ def test_binariseCateorical():
                 offset += 1
                 got = add[i]
                 assert addvids[i] == vid
-                assert got.name == '{}.{}'.format(vid, int(u))
+                assert got.name == '{}.{}'.format(vid, u)
                 assert (got == exp).all()
                 assert kwargs[i]['metadata'] == u
         assert names == [r.name for r in remove]
@@ -345,7 +351,7 @@ def test_binariseCateorical():
 @patch_logging
 def test_binariseCateorical_no_replace():
 
-    data = np.random.randint(1, 10, (50, 3))
+    data = np.random.randint(1, 10, (50, 3)).astype(np.float32)
     data[:, 0] = np.arange(1, 51)
     cols = ['eid', '1-0.0', '2-0.0']
     vids  = [1, 2]
@@ -436,7 +442,7 @@ def test_binariseCategorical_take():
             ['2-0.1', '2-0.2', '2-0.3', '2-0.4', '2-0.5']
     cols1 = ','.join(cols1)
     exp1  = tw.dedent("""
-    eid,1-0.A,1-0.B,1-0.C,1-0.D,1-0.E
+    eid,1-A,1-B,1-C,1-D,1-E
     1,1,2,3,4,5
     2,6,,,,
     3,,7,,8,9
@@ -575,6 +581,30 @@ def test_binariseCategorical_missing_vars():
         assert len(series) == 0
 
 
+# fsl/funpack!100
+def test_binariseCategorical_unique_colnames():
+
+    df = pd.DataFrame({'1-0.0' : pd.Series(['1', '01', '2', '002']),
+                       'eid'   : [1, 2, 3, 4]}).set_index('eid')
+
+    with tempdir():
+        df.to_csv('data.csv')
+        vartable, proctable, cattable = gen_tables(
+            [1], vtypes={1 : 'text'})[:3]
+        finfo = fileinfo.FileInfo('data.csv')
+        dt, _ = importing.importData(finfo, vartable, proctable, cattable)
+
+        series = pfns.binariseCategorical(dt, [1], acrossVisits=True)[1]
+        assert len(series) == 4
+        names = sorted([s.name for s in series])
+        assert names == sorted(['1-1', '1-01', '1-2', '1-002'])
+
+        got = pd.DataFrame({s.name : s for s in series})
+        assert (got['1-1']   == [1, 0, 0, 0]).all()
+        assert (got['1-01']  == [0, 1, 0, 0]).all()
+        assert (got['1-2']   == [0, 0, 1, 0]).all()
+        assert (got['1-002'] == [0, 0, 0, 1]).all()
+
 
 @patch_logging
 def test_expandCompound():
@@ -622,3 +652,123 @@ def test_expandCompound():
 
             assert np.all(        expna  ==         gotna)
             assert np.all(expcol[~expna] == gotcol[~gotna])
+
+
+
+@patch_logging
+def test_createDiagnosisColumns():
+
+    maxdiags = 8
+    nsubjs   = 10
+    maincols = [f'41270-0.{i}' for i in range(1, 1 + maxdiags)]
+    primcols = [f'41202-0.{i}' for i in range(1, 1 + maxdiags // 2)]
+    seccols  = [f'41204-0.{i}' for i in range(1, 1 + maxdiags // 2)]
+    allcols  = maincols + primcols + seccols
+    h        = hierarchy.loadHierarchyFile(hierarchy.getHierarchyFilePath(coding=19))
+    df       = pd.DataFrame(index=np.arange(1, nsubjs + 1), columns=allcols)
+    df.index.name = 'eid'
+
+    allcodes  = set()
+    primcodes = set()
+    seccodes  = set()
+
+    for subj in range(1, nsubjs + 1):
+        numdiags  = np.random.randint(1, maxdiags + 1, 1)[0]
+        maindiags = np.random.choice(np.arange(1, len(h.codings) + 1), numdiags)
+        maindiags = [h.codings[d] for d in maindiags]
+        primdiags = maindiags[:max(1, numdiags // 2)]
+        secdiags  = maindiags[ max(1, numdiags // 2):]
+
+        allcodes .update(maindiags)
+        primcodes.update(primdiags)
+        seccodes .update(secdiags)
+
+        maindiags = maindiags + [np.nan for _ in range(maxdiags      - len(maindiags))]
+        primdiags = primdiags + [np.nan for _ in range(maxdiags // 2 - len(primdiags))]
+        secdiags  = secdiags  + [np.nan for _ in range(maxdiags // 2 - len(secdiags))]
+
+        df.loc[subj, maincols] = maindiags
+        df.loc[subj, primcols] = primdiags
+        df.loc[subj, seccols]  = secdiags
+
+    def check(remove, add, addvids):
+        # check that there are new primary and
+        # secondary columns for each code
+        primadded = [s.name for s in add if s.name.startswith('41202')]
+        secadded  = [s.name for s in add if s.name.startswith('41204')]
+        primadded = [s.split('-', 1)[1].split('.')[0] for s in primadded]
+        secadded  = [s.split('-', 1)[1].split('.')[0] for s in secadded]
+
+        assert sorted(allcodes) == sorted(primadded)
+        assert sorted(allcodes) == sorted(secadded)
+
+        for col, vid in zip(add, addvids):
+            if col.name.startswith('41202'): assert vid == 41202
+            else:                            assert vid == 41204
+
+        # check that primary/secondary code
+        # columns are flagged for removal
+        assert sorted(primcols + seccols) == [r.name for r in remove]
+
+        # check that primary/secondary
+        # codes were flagged correctly
+        primadded = {}
+        secadded  = {}
+        for col in add:
+            code, ptype = col.name.split('-', 1)[1].split('.')
+
+            if ptype == 'primary': primadded[code] = col
+            else:                  secadded[ code] = col
+
+        for subj in df.index:
+            primdiags = df.loc[subj, primcols].dropna()
+            secdiags  = df.loc[subj, seccols] .dropna()
+
+            for d in primdiags:
+                assert primadded[d][subj] == 1
+                assert secadded[ d][subj] == 0
+            for d in secdiags:
+                assert primadded[d][subj] == 0
+                assert secadded[ d][subj] == 1
+
+    with tempdir():
+        df.to_csv('data.csv')
+
+        vartable, proctable, cattable = gen_tables(
+            [41270, 41202, 41204], vtypes={41270 : 'text',
+                                           41202 : 'text',
+                                           41204 : 'text'})[:3]
+        finfo = fileinfo.FileInfo('data.csv')
+
+        # test from raw data
+        dt, _ = importing.importData(finfo, vartable, proctable, cattable)
+        remove, add, addvids, _ = pfns.createDiagnosisColumns(dt, [41270], 41202, 41204)
+        check(remove, add, addvids)
+
+        # test from data that has been
+        # passed through binariseCategorical
+        dt, _ = importing.importData(finfo, vartable, proctable, cattable)
+        remove, add, addvids, kwargs = pfns.binariseCategorical(dt, [41270])
+        if len(remove) > 0: dt.removeColumns(remove)
+        if len(add)    > 0: dt.addColumns(add, addvids, kwargs)
+        remove, add, addvids, _ = pfns.createDiagnosisColumns(dt, [41270], 41202, 41204, binarised=True)
+        check(remove, add, addvids)
+
+
+
+@patch_logging
+def test_removeField():
+
+    v1 = np.random.random(100)
+    v2 = np.random.random(100)
+    v3 = np.random.random(100)
+
+    dtable = gen_DataTable([v1, v2, v3])
+    cols   = [None] + dtable.dataColumns
+
+    for vids in it.permutations([1, 2, 3], 2):
+        assert pfns.removeField(dtable, vids) == [cols[v] for v in vids]
+    for vids in it.permutations([1, 2, 3], 2):
+        assert pfns.removeField(dtable, vids) == [cols[v] for v in vids]
+    for vids in it.permutations([1, 2, 3], 3):
+        assert pfns.removeField(dtable, vids) == [cols[v] for v in vids]
